"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const database_1 = require("../utils/database");
const handleError_1 = require("../utils/handleError");
const uuid_1 = require("uuid");
const nodemailer_1 = __importDefault(require("nodemailer"));
const config_1 = require("../config/config");
class AdRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100) {
            throw new handleError_1.ValidationError('Nazwa nie może być pusta oraz nie może mieć więcej niż 100 znaków!');
        }
        if (obj.description.length > 1000) {
            throw new handleError_1.ValidationError('Opis nie może być dłuższy niż 1000 znaków!');
        }
        if (obj.price < 0 || obj.price > 9999999) {
            throw new handleError_1.ValidationError('Wartość produktu nie może być mniejsza niż 0 i większa od 9.999.999');
        }
        if (!obj.link || obj.link.length < 10) {
            throw new handleError_1.ValidationError('Link ogłoszenia jest niepoprawny lub nie istnieje');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.description = obj.description;
        this.price = obj.price;
        this.lat = obj.lat;
        this.lon = obj.lon;
        this.link = obj.link;
        this.visitors = obj.visitors;
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [allAds] = yield database_1.database.execute('SELECT * FROM `ad` WHERE `accepted` = 1');
            return allAds.map((obj) => new AdRecord(obj));
        });
    }
    static getOneAd(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield database_1.database.execute('UPDATE `ad` SET `visitors` = visitors + 1 WHERE `id` = :id', { id });
            const [getOne] = yield database_1.database.execute('SELECT * FROM `ad` WHERE `id` = :id', { id });
            return getOne.length === 0 ? null : new AdRecord(getOne[0]);
        });
    }
    add() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('UUID already exists in DB. Rejected request.');
            }
            try {
                const newAd = yield database_1.database.execute('INSERT INTO `ad` (id, name, description, price, lat, lon, link) VALUES (:id, :name, :description, :price, :lat, :lon, :link)', {
                    id: this.id,
                    name: this.name,
                    description: this.description,
                    price: this.price,
                    lat: this.lat,
                    lon: this.lon,
                    link: this.link,
                });
                const output = `
                   <a href="${config_1.config.cors}api/ad/admin/accepted/${this.id}">Link do akceptacji!</a>
                    `;
                let transporter = nodemailer_1.default.createTransport({
                    host: 'smtp.gmail.com',
                    port: 587,
                    secure: false,
                    auth: {
                        user: process.env.GMAIL,
                        pass: process.env.PASSWORD,
                    },
                    tls: {
                        rejectUnauthorized: false
                    }
                });
                yield transporter.sendMail({
                    from: '"Ad"',
                    to: process.env.GMAIL,
                    text: "Ad",
                    html: output
                });
                return {
                    id: this.id
                };
            }
            catch (e) {
                throw new Error(e.message);
            }
        });
    }
    static findInterestedAd(text) {
        return __awaiter(this, void 0, void 0, function* () {
            const [getAllInterested] = yield database_1.database.execute('SELECT * FROM `ad` WHERE `accepted` = 1 AND `name` LIKE :text', {
                text: `%${text}%`
            });
            return getAllInterested.length === 0 ? null : getAllInterested.map((obj) => {
                const { lat, lon, id, visitors } = obj;
                return {
                    id,
                    lat,
                    lon,
                    visitors,
                };
            });
        });
    }
    ;
    static acceptAd(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield database_1.database.execute('UPDATE `ad` SET `accepted` = 1 WHERE `id` = :id', { id });
        });
    }
    ;
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad-record.js.map